==> anki_0.9.5.7.orig.tar.gz: anki-0.9.5.7/ankiqt/ui/update.py <==
# Copyright: Damien Elmes <anki@ichi2.net>
# License: GNU GPL, version 3 or later; http://www.gnu.org/copyleft/gpl.html

from PyQt4.QtCore import *
from PyQt4.QtGui import *
import urllib, urllib2, os, sys, time
import anki, anki.utils, anki.lang, anki.stats
import ankiqt

baseUrl = "http://anki.ichi2.net/update/"

# when requesting latest version number, gather their version, deck size and
# average retention ratio for future development
# FIXME: add ability to disable in prefs, warn about anonymous sent info
class LatestVersionFinder(QThread):

    def __init__(self, main):
        QThread.__init__(self)
        self.main = main
        self.config = main.config
        # calculate stats before we start a new thread
        if self.main.deck != None:
            deckSize = self.main.deck.totalCardCount()
            stats = anki.stats.globalStats(self.main.deck.s)
            deckRecall = "%0.2f" % (
                (stats.matureEase3 + stats.matureEase4) /
                float(stats.matureEase0 +
                      stats.matureEase1 +
                      stats.matureEase2 +
                      stats.matureEase3 +
                      stats.matureEase4 + 0.000001) * 100)
            pending = "(%d, %d)" % (self.main.deck.oldCardCount(),
                                    self.main.deck.newCardCount())
            ct = self.main.deck.created
            if ct:
                ol = anki.lang.getLang()
                anki.lang.setLang("en")
                age = anki.utils.fmtTimeSpan(abs(
                    time.time() - ct))
                anki.lang.setLang(ol)
            else:
                age = ""
            plat=sys.platform
            pver=sys.version
        else:
            deckSize = "nodeck"
            deckRecall = ""
            pending = ""
            age = ""
            plat=""
            pver=""
        d = {"ver": ankiqt.appVersion,
             "size": deckSize,
             "rec": deckRecall,
             "pend": pending,
             "age": age,
             "pver": pver,
             "plat": plat,}
        self.stats = d

    def run(self):
        if not self.config['checkForUpdates']:
            return
        d = self.stats
        d = urllib.urlencode(d)
        try:
            f = urllib2.urlopen(baseUrl + "getQtVersion", d)
        except urllib2.URLError:
            return
        resp = f.read()
        if not resp:
            return
        if resp > ankiqt.appVersion:
            self.emit(SIGNAL("newVerAvail"), resp)

class Updater(QThread):

    filename = "anki-update.exe"
    # FIXME: get when checking version number
    chunkSize = 428027
    percChange = 5

    def __init__(self):
        QThread.__init__(self)

    def setStatus(self, msg, timeout=0):
        self.emit(SIGNAL("statusChanged"), msg, timeout)

    def run(self):
        filename = os.path.abspath(self.filename)
        try:
            f = urllib2.urlopen(baseUrl + "getQt")
        except urllib2.URLError:
            self.setStatus(_("Unable to reach server"))
            return
        try:
            newfile = open(filename, "wb")
        except:
            self.setStatus(_("Unable to open file"))
            return
        perc = 0
        while 1:
            self.setStatus(
                _("Downloading anki updater - %d%% complete.") % perc)
            resp = f.read(self.chunkSize)
            if not resp:
                break
            newfile.write(resp)
            perc += self.percChange
            if perc > 99:
                perc = 99
        newfile.close()
        self.setStatus(_("Updating.."))
        os.chdir(os.path.dirname(filename))
        os.system(os.path.basename(filename))
        self.setStatus(_("Update complete. Please restart Anki."))
        os.unlink(filename)

def askAndUpdate(parent, version=None):
    if not version:
        baseStr = _("<h1>Update Anki manually</h1>"
                    "Usually there is no need to do this. "
                    "You will be notified automatically "
                    "when a new version of Anki is available. ")
    else:
        baseStr = _("""<h1>Anki updated</h1>A new version of Anki is
        available.<br/>""")
    if sys.platform == "win32":
        # automated installer available
        ret = QMessageBox.question(
            parent, "Anki", baseStr +
            _("Would you like to download it now?"),
            QMessageBox.Yes | QMessageBox.No)
        if ret == QMessageBox.Yes:
            parent.autoUpdate = Updater()
            parent.connect(parent.autoUpdate,
                           SIGNAL("statusChanged"),
                           parent.setStatus)
            parent.autoUpdate.start()
    else:
        # manual
        ret = QMessageBox.question(
            parent, "Anki", baseStr +
            "Would you like to visit the website now?",
            QMessageBox.Yes | QMessageBox.No)
        if ret == QMessageBox.Yes:
            QDesktopServices.openUrl(QUrl(ankiqt.appWebsite))

==> anki_0.9.6.orig.tar.gz: anki-0.9.6/ankiqt/ui/update.py <==
# Copyright: Damien Elmes <anki@ichi2.net>
# License: GNU GPL, version 3 or later; http://www.gnu.org/copyleft/gpl.html

from PyQt4.QtCore import *
from PyQt4.QtGui import *
import urllib, urllib2, os, sys, time, httplib
import anki, anki.utils, anki.lang, anki.stats
import ankiqt
import simplejson

baseUrl = "http://anki.ichi2.net/update/"

# when requesting latest version number, gather their version, deck size and
# average retention ratio for future development
# FIXME: add ability to disable in prefs, warn about anonymous sent info
class LatestVersionFinder(QThread):

    def __init__(self, main):
        QThread.__init__(self)
        self.main = main
        self.config = main.config
        # calculate stats before we start a new thread
        if self.main.deck != None:
            deckSize = self.main.deck.totalCardCount()
            stats = anki.stats.globalStats(self.main.deck.s)
            deckRecall = "%0.2f" % (
                (stats.matureEase3 + stats.matureEase4) /
                float(stats.matureEase0 +
                      stats.matureEase1 +
                      stats.matureEase2 +
                      stats.matureEase3 +
                      stats.matureEase4 + 0.000001) * 100)
            pending = "(%d, %d)" % (self.main.deck.oldCardCount(),
                                    self.main.deck.newCardCount())
            ct = self.main.deck.created
            if ct:
                ol = anki.lang.getLang()
                anki.lang.setLang("en")
                age = anki.utils.fmtTimeSpan(abs(
                    time.time() - ct))
                anki.lang.setLang(ol)
            else:
                age = ""
            plat=sys.platform
            pver=sys.version
        else:
            deckSize = "nodeck"
            deckRecall = ""
            pending = ""
            age = ""
            plat=""
            pver=""
        d = {"ver": ankiqt.appVersion,
             "size": deckSize,
             "rec": deckRecall,
             "pend": pending,
             "age": age,
             "pver": pver,
             "plat": plat,}
        self.stats = d

    def run(self):
        if not self.config['checkForUpdates']:
            return
        d = self.stats
        d['proto'] = 2
        d = urllib.urlencode(d)
        try:
            f = urllib2.urlopen(baseUrl + "getQtVersion", d)
        except (urllib2.URLError, httplib.BadStatusLine):
            return
        resp = f.read()
        if not resp:
            return
        resp = simplejson.loads(resp)
        if resp['latestVersion'] > ankiqt.appVersion:
            self.emit(SIGNAL("newVerAvail"), resp)
        diff = resp['currentTime'] - time.time()
        if abs(diff) > 300:
            self.emit(SIGNAL("clockIsOff"), diff)

class Updater(QThread):

    filename = "anki-update.exe"
    # FIXME: get when checking version number
    chunkSize = 428027
    percChange = 5

    def __init__(self):
        QThread.__init__(self)

    def setStatus(self, msg, timeout=0):
        self.emit(SIGNAL("statusChanged"), msg, timeout)

    def run(self):
        filename = os.path.abspath(self.filename)
        try:
            f = urllib2.urlopen(baseUrl + "getQt")
        except urllib2.URLError:
            self.setStatus(_("Unable to reach server"))
            return
        try:
            newfile = open(filename, "wb")
        except:
            self.setStatus(_("Unable to open file"))
            return
        perc = 0
        while 1:
            self.setStatus(
                _("Downloading anki updater - %d%% complete.") % perc)
            resp = f.read(self.chunkSize)
            if not resp:
                break
            newfile.write(resp)
            perc += self.percChange
            if perc > 99:
                perc = 99
        newfile.close()
        self.setStatus(_("Updating.."))
        os.chdir(os.path.dirname(filename))
        os.system(os.path.basename(filename))
        self.setStatus(_("Update complete. Please restart Anki."))
        os.unlink(filename)

def askAndUpdate(parent, version=None):
    if not version:
        baseStr = _("<h1>Update Anki manually</h1>"
                    "Usually there is no need to do this. "
                    "You will be notified automatically "
                    "when a new version of Anki is available. ")
    else:
        baseStr = _("""<h1>Anki updated</h1>A new version of Anki is
        available.<br/>""")
    if sys.platform == "win32":
        # automated installer available
        ret = QMessageBox.question(
            parent, "Anki", baseStr +
            _("Would you like to download it now?"),
            QMessageBox.Yes | QMessageBox.No)
        if ret == QMessageBox.Yes:
            parent.autoUpdate = Updater()
            parent.connect(parent.autoUpdate,
                           SIGNAL("statusChanged"),
                           parent.setStatus)
            parent.autoUpdate.start()
    else:
        # manual
        ret = QMessageBox.question(
            parent, "Anki", baseStr +
            "Would you like to visit the website now?",
            QMessageBox.Yes | QMessageBox.No)
        if ret == QMessageBox.Yes:
            QDesktopServices.openUrl(QUrl(ankiqt.appWebsite))
